This package is provided information about Japan
================================================

PyPi: https://pypi.org/project/madookan/

Hello, this package is provided information about attractions Japan.

วิธีติดตั้ง
~~~~~~~~~~~

เปิด CMD / Terminal

.. code:: python

   pip install madookan

วิธีใช้งานแพ็คเพจนี้
~~~~~~~~~~~~~~~~~~~~

-  เปิด IDLE ขึ้นมาแล้วพิมพ์…

\```python from madoo import Look

japan = Look() # ประกาศชื่อ Class japan.info() # โชว์ Infomation
japan.about() # Information detail japan.show_art() # Show art
